@@ -38,9 +38,15 @@ def load_model(torch_nn_module, state_dict_path):
 
 
 class MovieMarkdownGenerator:
-    def __init__(self, movielens, tmdb_api_token):
+    def __init__(
+        self,
+        movielens,
+        tmdb_api_token,
+        placeholder_image_url="https://upload.wikimedia.org/wikipedia/commons/thumb/3/3f/Placeholder_view_vector.svg/681px-Placeholder_view_vector.svg.png",
+    ):
         self.movielens = movielens
         self.tmdb_api_token = tmdb_api_token
+        self.placeholder_image_url = placeholder_image_url
 
     @staticmethod
     def imdb_url(imdb_id):
@@ -82,14 +88,14 @@ class MovieMarkdownGenerator:
                 )
             )
             markdown = self.movielens["movies"].loc[movielens_id]["movie title"]
-            return markdown, ""
+            return markdown, self.placeholder_image_url
 
         movie_results = request.json()["movie_results"][0]
         poster_path = movie_results["poster_path"]
         if poster_path is not None:
             poster_url = self.poster_url_from_tmdb_poster_path(poster_path=poster_path)
         else:
-            poster_url = ""
+            poster_url = self.placeholder_image_url
         title = movie_results["title"]
         imdb_url = self.imdb_url(imdb_id=imdb_id)
         markdown = f"""[{title}]({imdb_url})"""
