@@ -247,6 +247,12 @@ class CatboostInterface(
         self.model.load_model("tmp")
         self._shap_explainer = pickle.loads(bytes_dict["shap_explainer_bytes"])
 
+    def setup_cache(self):
+        for kind in self.FeatureKind:
+            self.cached_indexed_features_dataframe(kind=kind)
+            if kind != self.FeatureKind.user_item:
+                self.cached_rating_stats(kind=kind)
+
     def user_features(self) -> FeatureReturnValue:
         """
         Returns FeatureReturnValue with these kwargs:
